summaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 20:06:11 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 20:33:38 +0900
commit7485c8248a1bb3a2fed851d389a291d60bba7752 (patch)
tree01530186491285c596ad8bea4ee9368436e38a48 /scripts
parent2611dd9a2020f335eff619aeeffc3730144ce657 (diff)
downloadtdesdk-7485c8248a1bb3a2fed851d389a291d60bba7752.tar.gz
tdesdk-7485c8248a1bb3a2fed851d389a291d60bba7752.zip
Replace QObject, QWidget, QImage, QPair, QRgb, QColor, QChar, QString, QIODevice with TQ* versionr14.1.1
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> (cherry picked from commit 0ffe839d6e363933ed4d9d212b6fd325a6fc3225)
Diffstat (limited to 'scripts')
-rw-r--r--scripts/add_trace.pl4
-rw-r--r--scripts/fixheaders6
-rwxr-xr-xscripts/includemocs4
-rwxr-xr-xscripts/kDebug2kdDebug.sh4
-rw-r--r--scripts/kde-devel-gdb12
-rw-r--r--scripts/kde-devel-vim.vim2
-rw-r--r--scripts/kde-emacs/klaralv.el2
7 files changed, 17 insertions, 17 deletions
diff --git a/scripts/fixheaders b/scripts/fixheaders
index 73c7b581..eb9dbeb4 100644
--- a/scripts/fixheaders
+++ b/scripts/fixheaders
@@ -57,7 +57,7 @@ $lastdir = '.';
'`QUriDrag\' undeclared \(first use this function\)' => "qdragobject",
'`kdDebug\' undeclared \(first use this function\)' => "kdebug",
'`kdWarning\' undeclared \(first use this function\)' => "kdebug",
- 'no matching function for call to `KMenuBar::insertItem\(QString, TDEPopupMenu' => "tdepopupmenu",
+ 'no matching function for call to `KMenuBar::insertItem\(TQString, TDEPopupMenu' => "tdepopupmenu",
'no matching function for call to `KMenuBar::' => "kmenubar",
'invalid use of undefined type `class QPointArray' => "qpointarray",
'variable `QPainter \S*\' has initializer but incomplete type' => "qpainter",
@@ -79,7 +79,7 @@ $lastdir = '.';
'`DCOPClient\' undeclared \(first use this function\)' => "dcopclient",
'invalid use of undefined type `class KStatusBar\'' => "kstatusbar",
'invalid use of undefined type `class QLabel\'' => "qlabel",
- 'invalid use of undefined type `class QImage\'' => "qimage",
+ 'invalid use of undefined type `class TQImage\'' => "qimage",
'invalid use of undefined type `class QImageIO\'' => "qimage",
'invalid use of undefined type `class QLineEdit\'' => "qlineedit",
'invalid use of undefined type `class QComboBox\'' => "qcombobox",
@@ -97,7 +97,7 @@ $lastdir = '.';
'error: incomplete type `Q3ValueList' => 'q3valuelist',
'error: variable `Q3ValueList<' => 'q3valuelist',
'error: `Q3PointArray\' undeclared' => 'q3pointarray',
- 'error: invalid use of undefined type \`struct QColor' => 'qcolor',
+ 'error: invalid use of undefined type \`struct TQColor' => 'qcolor',
'error: `QX11Info::' => 'qx11info_x11',
'error: incomplete type \'QX11Info' => 'qx11info_x11',
'error: \'Q3AsciiDi' => 'q3asciidict'
diff --git a/scripts/includemocs b/scripts/includemocs
index 3b2c87f0..a96d4fd7 100755
--- a/scripts/includemocs
+++ b/scripts/includemocs
@@ -71,14 +71,14 @@ includemocs -- handle mocifyable headers, whose .moc file is nowhere included.
=head1 DESCRIPTION
-Header files declaring a QObject descendant have to be run through moc to
+Header files declaring a TQObject descendant have to be run through moc to
produce a .moc file. This .moc file has to be compiled, for which two
possibilities exists: compile it separately, or #include it in the C++ file
implementing that above mentioned class. The latter is more efficient in term
of compilation speed.
This script searches in the current directory and its subdirs for header files
-declaring a QObject descendant class. If it finds some, it looks, if there is
+declaring a TQObject descendant class. If it finds some, it looks, if there is
a C++ file containing an '#include' for the generated .moc file. If thats not
the case, it tries to guess into which C++ file that '#include' is placed best
(based on the filename). If it fails to guess a proper place, it mentions
diff --git a/scripts/kde-devel-gdb b/scripts/kde-devel-gdb
index 62a43aba..3901803e 100644
--- a/scripts/kde-devel-gdb
+++ b/scripts/kde-devel-gdb
@@ -12,7 +12,7 @@ define printqstring
printqstringdata $arg0.d
end
document printqstring
- Prints the contents of a QString
+ Prints the contents of a TQString
end
define printq4string
printq4stringdata $arg0.d
@@ -32,8 +32,8 @@ end
document printqstringdata
Prints the contents of a QStringData
This is useful when the output of another command (e.g. printqmap)
- shows {d = 0xdeadbeef} for a QString, i.e. the qstringdata address
- instead of the QString object itself.
+ shows {d = 0xdeadbeef} for a TQString, i.e. the qstringdata address
+ instead of the TQString object itself.
printqstring $s and printqstringdata $s.d are equivalent.
end
@@ -73,7 +73,7 @@ define printqstring_utf8
printf "\n"
end
document printqstring_utf8
- Prints the contents of a QString encoded in utf8.
+ Prints the contents of a TQString encoded in utf8.
Nice if you run your debug session in a utf8 enabled terminal.
end
@@ -106,8 +106,8 @@ define printqcolor
printf "(%d,%d,%d)\n", ($arg0).red(), ($arg0).green(), ($arg0).blue()
end
document printqcolor
- Prints a QColor as (R,G,B).
- Usage: 'printqcolor <QColor col>
+ Prints a TQColor as (R,G,B).
+ Usage: 'printqcolor <TQColor col>
end
define printqmemarray
diff --git a/scripts/kde-devel-vim.vim b/scripts/kde-devel-vim.vim
index 4e9eaf65..a1832c51 100644
--- a/scripts/kde-devel-vim.vim
+++ b/scripts/kde-devel-vim.vim
@@ -215,7 +215,7 @@ function! MapIdentHeader( ident )
return '<qvalidator.h>'
elseif a:ident =~ 'QListBox.*'
return '<qlistbox.h>'
- elseif a:ident == 'QChar' ||
+ elseif a:ident == 'TQChar' ||
\a:ident == 'QCharRef' ||
\a:ident == 'QConstString'
return '<qstring.h>'
diff --git a/scripts/kde-emacs/klaralv.el b/scripts/kde-emacs/klaralv.el
index 2b6989c4..d93fa0ff 100644
--- a/scripts/kde-emacs/klaralv.el
+++ b/scripts/kde-emacs/klaralv.el
@@ -73,7 +73,7 @@
(qaction.h QActionGroup)
(qvalidator.h QIntValidator QDoubleValidator QRegExpValidator)
(qlistbox.h QListBoxItem QListBoxText QListBoxPixmap)
- (qstring.h QChar QCharRef QConstString)
+ (qstring.h TQChar QCharRef QConstString)
(qcanvas.h QCanvasSprite QCanvasPolygonalItem QCanvasRectangle
QCanvasPolygon QCanvasEllipse QCanvasText QCanvasLine
QCanvasChunk QCanvas QCanvasItem QCanvasView QCanvasPixmap)
diff --git a/scripts/add_trace.pl b/scripts/add_trace.pl
index bad152c3..cf073a3b 100644
--- a/scripts/add_trace.pl
+++ b/scripts/add_trace.pl
@@ -97,8 +97,8 @@ while (<>)
elsif ( m/^bool\s+([a-zA-Z0-9_]+)/ ) {
$line = $line . " << \" $1=\" << (" . $1 . " ? \"true\" : \"false\" )";
}
- ## QString and friends
- elsif ( m/QString[\&\s]+([a-zA-Z0-9_]+)/ || m/QCString[\&\s]*([a-zA-Z0-9_]+)/ ) {
+ ## TQString and friends
+ elsif ( m/TQString[\&\s]+([a-zA-Z0-9_]+)/ || m/QCString[\&\s]*([a-zA-Z0-9_]+)/ ) {
$line = $line . " << \" $1=\" << " . $1;
}
## KURL
diff --git a/scripts/kDebug2kdDebug.sh b/scripts/kDebug2kdDebug.sh
index 2a08b610..871bc439 100755
--- a/scripts/kDebug2kdDebug.sh
+++ b/scripts/kDebug2kdDebug.sh
@@ -99,8 +99,8 @@ while (<>)
if ( /(%[0-9]*[a-z])/ ) # This item is a format
{
## 3 - Find argument
- # kludge for QString(a,b) constructions
- $arguments =~ s/(QString\s*\([^,]+,[^,]+\))/QStrKLUDGE/;
+ # kludge for TQString(a,b) constructions
+ $arguments =~ s/(TQString\s*\([^,]+,[^,]+\))/QStrKLUDGE/;
$kludge = $1;
$arguments =~ s/\s*([^,]+)\s*,//;
# Remove trailing .ascii() and latin1()